from setuptools import setup

setup(name='fares_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions'],
      author = 'Fares',
      author_email = 'gdourafares@gmail.com',
      zip_safe=False)
